#!/usr/bin/env bash

# Проверка количества аргументов
if [ $# -ne 3 ]; then
  echo "Usage: $0 <PORT> <VIDEO_PATH> <VIDEO_LOCATION>"
  exit 1
fi

VIDEO_HOSTING_PORT=$1
VIDEO_HOSTING_PATH=$2
VIDEO_LOCATION=$3

# Завершение всех предыдущих процессов Caddy
echo "Stopping any running Caddy processes..."
pkill -f "caddy run" &>/dev/null

# Убедимся, что Caddy установлен
if ! command -v caddy &> /dev/null; then
  echo "Caddy is not installed. Installing it via Homebrew..."
  brew install caddy
fi

# Проверяем, существует ли путь к видео
if [ ! -d "$VIDEO_HOSTING_PATH" ]; then
  echo "Directory $VIDEO_HOSTING_PATH does not exist."
  exit 1
fi

# Проверяем, свободен ли порт
if lsof -i:"$VIDEO_HOSTING_PORT" &>/dev/null; then
  echo "Port $VIDEO_HOSTING_PORT is already in use. Please choose a different port."
  exit 1
fi

# Создаем конфигурационный файл для Caddy
CADDY_CONF_DIR="$HOME/.caddy"
mkdir -p $CADDY_CONF_DIR
CADDY_CONF_FILE="${CADDY_CONF_DIR}/Caddyfile"

cat <<EOF > "$CADDY_CONF_FILE"
http://:${VIDEO_HOSTING_PORT} {
    handle_path ${VIDEO_LOCATION}* {
        root * "${VIDEO_HOSTING_PATH}"
        file_server browse
    }
}
EOF

# Форматируем Caddyfile
caddy fmt --overwrite "$CADDY_CONF_FILE"

# Запуск Caddy в фоновом режиме
echo "Starting Caddy server on port $VIDEO_HOSTING_PORT..."
nohup caddy run --config "$CADDY_CONF_FILE" > /tmp/caddy.log 2>&1 &

# Проверка успешного запуска
if [ $? -eq 0 ]; then
  echo "Caddy is serving files from ${VIDEO_HOSTING_PATH} at http://localhost:${VIDEO_HOSTING_PORT}${VIDEO_LOCATION}"
else
  echo "Error: Failed to start Caddy server. Check the logs for details."
  exit 1
fi
