#!/usr/bin/env bash

# Check if we have exactly 2 arguments
if [ $# -ne 3 ]; then
  echo "Usage: $0 <PORT> <VIDEO_PATH> <VIDEO_LOCATION>"
  exit 1
fi

VIDEO_HOSTING_PORT=$1
VIDEO_HOSTING_PATH=$2
VIDEO_LOCATION=$3

NGINX_CONF_DIR="/opt/homebrew/etc/nginx/servers"

if [ ! -d "$NGINX_CONF_DIR" ]; then
  echo "Nginx servers directory not found at $NGINX_CONF_DIR"
  echo "Make sure Nginx is installed via Homebrew and directory is correct."
  exit 1
fi

chmod -R 777 ${VIDEO_HOSTING_PATH}

cat <<EOF > "${NGINX_CONF_DIR}/video_hosting.conf"
server {
    listen ${VIDEO_HOSTING_PORT};

    location ${VIDEO_LOCATION} {
        alias "${VIDEO_HOSTING_PATH}";
        autoindex on;
        autoindex_exact_size off;
        autoindex_localtime on;

        # Optimization for large files
        sendfile on;
        tcp_nopush on;
        tcp_nodelay on;
        # aio threads;
        # directio 4m;

        # Set headers for Range requests
        open_file_cache max=1000 inactive=20s;
        open_file_cache_valid 30s;
        open_file_cache_min_uses 2;
        open_file_cache_errors on;

        # Improve transfer speed
        client_body_buffer_size 128k;
        proxy_buffering off;
        proxy_cache_bypass \$http_range;
    }
}
EOF

nginx -s reload
# brew services restart nginx

echo "Nginx reloaded with new video hosting config."
echo "Try accessing: http://localhost:${VIDEO_HOSTING_PORT}${VIDEO_LOCATION}"
